@@ -1,11 +1,13 @@
 from __future__ import annotations
 
 import inspect
+from collections.abc import Iterable
 from io import TextIOWrapper
 from pathlib import Path
 from pkgutil import iter_modules
-from typing import Any, Iterable
+from typing import Any
 
+import jetpytools
 import mkdocs_gen_files
 import vspreview
 import vstransitions
@@ -17,6 +19,7 @@ import vsdehalo
 import vsdeinterlace
 import vsdenoise
 import vsexprtools
+import vsjetpack
 import vskernels
 import vsmasktools
 import vsrgtools
@@ -26,12 +29,14 @@ import vstools
 
 # Modules to document.
 MODULES = [
+    jetpytools,
     vsaa,
     vsdeband,
     vsdehalo,
     vsdeinterlace,
     vsdenoise,
     vsexprtools,
+    vsjetpack,
     vskernels,
     vsmasktools,
     vspreview,
