@@ -1,7 +1,7 @@
 from unittest import TestCase
 
 from vstools import get_prop, vs
-from vstools.enums.other import Dar, Resolution, Sar
+from vstools.enums.other import Dar, Sar
 
 
 class TestDar(TestCase):
@@ -27,15 +27,3 @@ class TestSar(TestCase):
         clip = Sar(1920, 1).apply(clip)
         self.assertEqual(get_prop(clip, "_SARNum", int), 1920)
         self.assertEqual(get_prop(clip, "_SARDen", int), 1)
-
-
-class TestResolution(TestCase):
-    def test_from_video(self) -> None:
-        clip = vs.core.std.BlankClip(format=vs.YUV420P8, width=640, height=480)
-        self.assertEqual(Resolution.from_video(clip), (640, 480))
-
-        clip = vs.core.std.BlankClip(format=vs.YUV420P8, width=1920, height=1080)
-        self.assertEqual(Resolution.from_video(clip), (1920, 1080))
-
-    def test_transpose(self) -> None:
-        self.assertEqual(Resolution(640, 480).transpose(), Resolution(480, 640))
