@@ -1,9 +1,12 @@
 from unittest import TestCase
 
+import pytest
+
 from vstools import (
     ColorRange,
     DitherType,
     UnsupportedColorFamilyError,
+    core,
     depth,
     get_b,
     get_g,
@@ -12,6 +15,7 @@ from vstools import (
     get_v,
     get_y,
     plane,
+    stack_planes,
     vs,
 )
 
@@ -63,7 +67,7 @@ class TestUtils(TestCase):
         self.assertEqual(src_10.format.name, "YUV420P10")
 
         src2_10 = vs.core.std.BlankClip(format=vs.RGB30)
-        src2_8 = depth(src2_10, 8, dither_type=DitherType.RANDOM)
+        src2_8 = depth(src2_10, 8)
         assert src2_8.format
         self.assertEqual(src2_8.format.name, "RGB24")
 
@@ -138,3 +142,15 @@ class TestUtils(TestCase):
         result = plane(clip, 0)
         assert result.format
         self.assertEqual(result.format.name, "Gray8")
+
+
+formats = [fmt for fmt in vs.PresetVideoFormat if fmt]
+
+
+@pytest.mark.parametrize(
+    "clip",
+    [core.std.BlankClip(format=fmt) for fmt in formats],
+    ids=[f"{fmt.name}/{fmt}" for fmt in formats],
+)
+def test_stack_plane(clip: vs.VideoNode) -> None:
+    stack_planes(clip)
