@@ -1,11 +1,14 @@
 from __future__ import annotations
 
 from abc import ABC, abstractmethod
+from collections import UserDict
+from collections.abc import Mapping, Sequence
 from dataclasses import dataclass, replace
 from enum import IntFlag, auto
-from typing import TYPE_CHECKING, Any, Mapping, Self, Sequence
+from fractions import Fraction
+from typing import TYPE_CHECKING, Any, Self, cast
 
-from jetpytools import CustomNotImplementedError, CustomValueError, copy_signature, fallback, normalize_seq
+from jetpytools import CustomNotImplementedError, CustomValueError, fallback, normalize_seq
 
 from vsjetpack import TypeVar
 from vskernels import (
@@ -34,36 +37,24 @@ __all__ = [
 ]
 
 
-class DeinterlacerKwargs(dict[str, Any]):
+class DeinterlacerKwargs(UserDict[str, Any]):
     """
     A dict-like wrapper that syncs keys with a `Deinterlacer` instance.
 
     - If a key matches an attribute of `deinterlacer`, the value is set on
       the object instead of stored in the dict.
     - Otherwise, the pair is stored normally.
-
-    `update()` and `setdefault()` are overridden to respect this behavior.
     """
 
-    deinterlacer: Deinterlacer
-    """Deinterlacer object."""
+    def __init__(self, deinterlacer: Deinterlacer) -> None:
+        self.deinterlacer = deinterlacer
+        super().__init__()
 
     def __setitem__(self, key: str, value: Any) -> None:
         if not hasattr(self.deinterlacer, key):
             return super().__setitem__(key, value)
         setattr(self.deinterlacer, key, value)
 
-    @copy_signature(dict[str, Any].update)
-    def update(self, *args: Any, **kwargs: Any) -> None:
-        for k, v in dict(*args, **kwargs).items():
-            self[k] = v
-
-    @copy_signature(dict[str, Any].setdefault)
-    def setdefault(self, key: str, default: Any = None) -> Any:
-        if key not in self:
-            self[key] = default
-        return self[key]
-
 
 @dataclass(kw_only=True)
 class Deinterlacer(Bobber, ABC):
@@ -78,8 +69,8 @@ class Deinterlacer(Bobber, ABC):
     """Whether to double the FPS."""
 
     def __post_init__(self) -> None:
-        self.kwargs = DeinterlacerKwargs()
-        self.kwargs.deinterlacer = self
+        # UserDict inherits from MutableMapping but they share the same methods
+        self.kwargs = cast(dict[str, Any], DeinterlacerKwargs(self))
 
     def deinterlace(
         self,
@@ -284,6 +275,7 @@ class SuperSampler(Scaler, AntiAliaser, ABC):
         dims = self._wh_norm(clip, width, height)
         dest_dimensions = list(dims)
         sy, sx = shift
+        in_width, in_height = clip.width, clip.height
 
         cloc = list(ChromaLocation.from_video(clip).get_offsets(clip))
         subsampling = [2**clip.format.subsampling_w, 2**clip.format.subsampling_h]
@@ -336,7 +328,11 @@ class SuperSampler(Scaler, AntiAliaser, ABC):
                 for i in range(len(ns)):
                     ns[i] *= not noshift[i]
 
-        return ComplexScaler.ensure_obj(self.scaler, self.__class__).scale(clip, width, height, (nshift[1], nshift[0]))
+        sar_scale = Fraction(clip.height // in_height, clip.width // in_width)
+
+        return ComplexScaler.ensure_obj(self.scaler, self.__class__).scale(
+            clip, width, height, (nshift[1], nshift[0]), _sar_scale=sar_scale
+        )
 
     if TYPE_CHECKING:
 
