@@ -4,12 +4,14 @@ This module implements functions based on the famous dehalo_alpha.
 
 from __future__ import annotations
 
-from typing import Any, Iterator, Sequence, TypeGuard
+from collections.abc import Iterator, Sequence
+from typing import Any, TypeGuard
 
 from jetpytools import CustomIndexError, FuncExcept, mod_x, normalize_seq
 
 from vsdenoise import Prefilter
 from vsexprtools import norm_expr
+from vsjetpack import deprecated
 from vskernels import BSpline, Lanczos, Mitchell, Scaler
 from vsmasktools import Morpho
 from vsrgtools import gauss_blur, repair
@@ -191,6 +193,7 @@ def dehalo_alpha(
     return out
 
 
+@deprecated("AlphaBlur is deprecated.", category=PendingDeprecationWarning)
 class AlphaBlur:
     """
     A Gaussian blur approximation inspired by Dehalo_Alpha.
