@@ -4,22 +4,25 @@ This module implements utilities for correcting dirty or damaged borders.
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, SupportsIndex, TypeAlias
+from typing import TYPE_CHECKING, Any, SupportsIndex
 
 from jetpytools import CustomOverflowError, CustomTypeError, FuncExcept, normalize_seq
-from typing_extensions import TypeIs
 
 from vsexprtools import ExprList, ExprOp, ExprToken, norm_expr
-from vstools import check_variable_format, get_lowest_values, get_peak_values, get_resolutions, vs, vs_object
+from vsjetpack import TypeIs
+from vstools import VSObject, get_lowest_values, get_peak_values, get_resolutions, vs
 
 __all__ = ["FixBorderBrightness"]
 
 if TYPE_CHECKING:
-    NoneSlice: TypeAlias = slice[None, None, None] | None
-    IndexLike: TypeAlias = SupportsIndex | slice[SupportsIndex, SupportsIndex, SupportsIndex]
+    type NoneSlice = slice[None, None, None] | None
+    """A slice with all components possibly None, or None itself."""
+
+    type IndexLike = SupportsIndex | slice[SupportsIndex, SupportsIndex, SupportsIndex]
+    """Either an integer-like index or a fully-typed slice."""
 else:
-    NoneSlice: TypeAlias = slice | None
-    IndexLike: TypeAlias = SupportsIndex | slice
+    type NoneSlice = slice | None
+    type IndexLike = SupportsIndex | slice
 
 
 def _normalize_slice(index: IndexLike | NoneSlice, length: int, func: FuncExcept) -> slice:
@@ -61,7 +64,7 @@ class _BorderDict(dict[int, float]):
         super().__init__()
 
 
-class FixBorderBrightness(vs_object):
+class FixBorderBrightness(VSObject):
     """
     Utility class to adjust or correct brightness inconsistencies along clip borders.
 
@@ -95,7 +98,6 @@ class FixBorderBrightness(vs_object):
                    - If a tuple `(low, high)` is given, applies it as a protection range.
                    - If a list of tuples is provided, applies individual protection ranges per plane.
         """
-        assert check_variable_format(clip, self.__class__)
         self.clip = clip
 
         ws, hs = zip(*((w, h) for _, w, h in get_resolutions(clip)))
@@ -104,7 +106,7 @@ class FixBorderBrightness(vs_object):
         self._tofix_rows = {i: _BorderDict(h) for i, h in enumerate(hs)}
 
         if protect is True:
-            protect = [(low, hight) for low, hight in zip(get_lowest_values(clip), get_peak_values(clip))]
+            protect = list(zip(get_lowest_values(clip), get_peak_values(clip)))
         elif protect is False:
             protect = [(False, False)]
         elif isinstance(protect, tuple):
@@ -297,6 +299,3 @@ class FixBorderBrightness(vs_object):
         return norm_expr(
             self.clip, tuple(exprs), func=self.__class__, **kwargs, protect_lo=protect_lo, protect_hi=protect_hi
         )
-
-    def __vs_del__(self, core_id: int) -> None:
-        del self.clip
