@@ -1,8 +1,9 @@
 from __future__ import annotations
 
+from collections.abc import Callable, Sequence
 from functools import cache
 from types import MappingProxyType
-from typing import Any, Callable, Sequence
+from typing import Any
 
 from jetpytools import (
     CustomEnum,
