@@ -5,8 +5,9 @@ This module implements wrappers for FFT (Fast Fourier Transform) based plugins.
 from __future__ import annotations
 
 import math
+from collections.abc import Iterator, Mapping, Sequence
 from functools import cache
-from typing import TYPE_CHECKING, Any, Iterator, Literal, Mapping, Self, Sequence, overload
+from typing import TYPE_CHECKING, Any, Literal, Self, overload
 
 from jetpytools import (
     CustomEnum,
@@ -1113,6 +1114,3 @@ The sequence or mapping must represent a pairing of frequency and sigma values f
 In the case of a sequence like `Sequence[Frequency, Sigma]`, it is essential that the number of items is even,
 ensuring every frequency has an associated sigma.
 """
-
-SLocationT = SLocationLike
-"""Deprecated alias of SLocationLike."""
