@@ -1,13 +1,15 @@
 from __future__ import annotations
 
+from collections.abc import Mapping
 from fractions import Fraction
 from itertools import chain
-from typing import Any, Literal, Mapping, NamedTuple, Union, overload
+from typing import Any, Literal, NamedTuple, overload
 
 from jetpytools import KwargsNotNone, fallback, normalize_seq
 
 from vstools import (
     ColorRange,
+    DitherType,
     Field,
     Planes,
     UnsupportedColorFamilyError,
@@ -168,6 +170,10 @@ class MVTools(VSObject):
         The main method of measuring block similarity is by calculating the sum of absolute differences (SAD)
         of all pixels of these two blocks, which indicates how correct the motion estimation was.
 
+        More information:
+            - [VapourSynth plugin](https://github.com/dubhater/vapoursynth-mvtools)
+            - [AviSynth docs](https://htmlpreview.github.io/?https://github.com/pinterf/mvtools/blob/mvtools-pfmod/Documentation/mvtools2.html)
+
         Args:
             clip: The clip to process.
             search_clip: Optional clip or callable to be used for motion vector gathering only.
@@ -375,7 +381,9 @@ class MVTools(VSObject):
             These vectors describe the estimated motion between frames and can be used for motion compensation.
         """
 
-        super_clip = self.super(fallback(super, self.search_clip), levels=levels)
+        super_clip = self.super(
+            fallback(super, self.search_clip), levels=fallback(levels, self.analyze_args.get("levels"), 0)
+        )
 
         blksize, blksizev = normalize_seq(blksize, 2)
         overlap, overlapv = normalize_seq(overlap, 2)
@@ -582,11 +590,7 @@ class MVTools(VSObject):
         thscd: int | tuple[int | None, float | None] | None = None,
         interleave: bool = True,
         temporal_func: VSFunctionNoArgs | None = None,
-    ) -> Union[
-        vs.VideoNode,
-        tuple[list[vs.VideoNode], list[vs.VideoNode]],
-        tuple[vs.VideoNode, tuple[int, int]],
-    ]:
+    ) -> vs.VideoNode | tuple[list[vs.VideoNode], list[vs.VideoNode]] | tuple[vs.VideoNode, tuple[int, int]]:
         """
         Perform motion compensation by moving blocks from reference frames to the current frame
         according to motion vectors.
@@ -718,11 +722,7 @@ class MVTools(VSObject):
         thscd: int | tuple[int | None, float | None] | None = None,
         interleave: bool = True,
         temporal_func: VSFunctionNoArgs | None = None,
-    ) -> Union[
-        vs.VideoNode,
-        tuple[list[vs.VideoNode], list[vs.VideoNode]],
-        tuple[vs.VideoNode, tuple[int, int]],
-    ]:
+    ) -> vs.VideoNode | tuple[list[vs.VideoNode], list[vs.VideoNode]] | tuple[vs.VideoNode, tuple[int, int]]:
         """
         Performs motion compensation using pixel-level motion vectors interpolated from block vectors.
 
@@ -1126,7 +1126,7 @@ class MVTools(VSObject):
 
         mask_clip = core.mv.Mask(depth(clip, 8), vect, **mask_args)
 
-        return depth(mask_clip, clip, range_in=ColorRange.FULL, range_out=ColorRange.FULL)
+        return depth(mask_clip, clip, dither_type=DitherType.NONE, range_in=ColorRange.FULL, range_out=ColorRange.FULL)
 
     def sc_detection(
         self,
