@@ -2,11 +2,11 @@ from __future__ import annotations
 
 import re
 import sys
+from collections.abc import Callable, Iterable, Sequence
 from itertools import groupby
 from logging import getLogger
 from math import ceil
-from typing import Any, Callable, Iterable, Sequence, SupportsIndex
-from warnings import warn
+from typing import Any, SupportsIndex
 
 from jetpytools import CustomIndexError, CustomRuntimeError, FuncExcept, StrList, SupportsString, normalize_seq, to_arr
 
@@ -28,7 +28,7 @@ if sys.version_info >= (3, 14):
     from string.templatelib import Template
 
 from .error import CustomExprError
-from .exprop import ExprList, ExprOp, ExprOpBase, TupleExprList, _TokenDeprecation
+from .exprop import ExprList, ExprOp, ExprOpBase, TupleExprList
 from .util import ExprVars
 
 __all__ = ["combine", "combine_expr", "expr_func", "norm_expr"]
@@ -84,7 +84,7 @@ def expr_func(
 
     clips = to_arr(clips)
 
-    fmt = get_video_format(format).id if format is not None else None
+    fmt = get_video_format(format) if format is not None else None
 
     _log.debug("expr_func (%s): %s", func, _LazyLogExpr(expr))
 
@@ -325,14 +325,6 @@ def bitdepth_aware_tokenize_expr(
         if token.value in expr:
             replaces.append((token.value, token.get_value))
 
-        if token.name in expr:
-            warn(
-                f"Using token name '{token.name}' in expressions is deprecated. "
-                "Use the token's string representation or its value instead.",
-                _TokenDeprecation,
-            )
-            replaces.append((f"{token.__class__.__name__}.{token.name}", token.get_value))
-
     if not replaces:
         return expr
 
