@@ -4,16 +4,17 @@ This module defines the base abstract interfaces for general scaling operations.
 
 from __future__ import annotations
 
+from collections.abc import Callable
 from functools import cache, wraps
+from inspect import isabstract
+from logging import getLogger
 from math import ceil
 from types import NoneType
 from typing import (
     TYPE_CHECKING,
     Any,
-    Callable,
     ClassVar,
     Concatenate,
-    Literal,
     NoReturn,
     Self,
     SupportsInt,
@@ -81,46 +82,14 @@ __all__ = [
     "ScalerLike",
 ]
 
+logger = getLogger(__name__)
 
-def _add_init_kwargs[_BaseScalerT: BaseScaler, **P, R](
-    method: Callable[Concatenate[_BaseScalerT, P], R],
-) -> Callable[Concatenate[_BaseScalerT, P], R]:
+
+def _add_init_kwargs[BaseScalerT: BaseScaler, **P, R](
+    method: Callable[Concatenate[BaseScalerT, P], R],
+) -> Callable[Concatenate[BaseScalerT, P], R]:
     @wraps(method)
-    def _wrapped(self: _BaseScalerT, *args: P.args, **kwargs: P.kwargs) -> R:
-        # TODO: remove this
-        if not TYPE_CHECKING and isinstance(self, vs.VideoNode):
-            import inspect
-            import pathlib
-            import re
-            import warnings
-
-            class _SyntaxMethod(DeprecationWarning, SyntaxWarning): ...
-
-            warnings.simplefilter("always", _SyntaxMethod)
-            warnings.warn(
-                f"The `{method.__name__}` method must be called on an instance, not the class. "
-                "For example, use: Bicubic().scale(...) instead of Bicubic.scale(...)",
-                _SyntaxMethod,
-                2,
-                skip_file_prefixes=(str(pathlib.Path(__file__).resolve()),),
-            )
-
-            frame_infos = inspect.stack()
-            frame_info = frame_infos[1]
-            f0 = inspect.currentframe()
-            f1 = f0.f_back  # pyright: ignore
-
-            try:
-                if code := frame_info.code_context:
-                    match = re.search(rf"(\w+)\.{method.__name__}", code[0])
-                    if match:
-                        clip = self
-                        self = eval(match.group(1), f1.f_globals, f1.f_locals)()  # pyright: ignore
-                        args = (clip, *args)  # pyright: ignore
-            finally:
-                frame_infos.clear()
-                del frame_info, f0, f1
-
+    def _wrapped(self: BaseScalerT, *args: P.args, **kwargs: P.kwargs) -> R:
         init_kwargs = {k: self.kwargs.pop(k) for k in self.kwargs.keys() & method.__annotations__.keys()}
 
         returned = method(self, *args, **init_kwargs | kwargs)
@@ -134,12 +103,12 @@ def _add_init_kwargs[_BaseScalerT: BaseScaler, **P, R](
     return _wrapped
 
 
-def _base_from_param[_BaseScalerT: BaseScaler](
-    cls: type[_BaseScalerT],
-    value: str | type[_BaseScalerT] | _BaseScalerT | None,
+def _base_from_param[BaseScalerT: BaseScaler](
+    cls: type[BaseScalerT],
+    value: str | type[BaseScalerT] | BaseScalerT | None,
     exception_cls: type[_UnknownBaseScalerError],
     func_except: FuncExcept | None,
-) -> type[_BaseScalerT]:
+) -> type[BaseScalerT]:
     # If value is an instance returns the class
     if isinstance(value, cls):
         return value.__class__
@@ -167,9 +136,9 @@ def _base_from_param[_BaseScalerT: BaseScaler](
     raise exception_cls(func_except or cls.from_param, str(value))
 
 
-def _base_ensure_obj[_BaseScalerT: BaseScaler](
-    cls: type[_BaseScalerT], value: str | type[_BaseScalerT] | _BaseScalerT | None, func_except: FuncExcept | None
-) -> _BaseScalerT:
+def _base_ensure_obj[BaseScalerT: BaseScaler](
+    cls: type[BaseScalerT], value: str | type[BaseScalerT] | BaseScalerT | None, func_except: FuncExcept | None
+) -> BaseScalerT:
     if isinstance(value, cls):
         return value
 
@@ -177,18 +146,8 @@ def _base_ensure_obj[_BaseScalerT: BaseScaler](
 
 
 @cache
-def _check_kernel_radius(cls: type[BaseScaler]) -> Literal[True]:
-    if cls in abstract_kernels:
-        raise CustomRuntimeError(f"Can't instantiate abstract class {cls.__name__}!", cls)
-
-    if "kernel_radius" in {attr for sub_cls in cls.__mro__ for attr in sub_cls.__dict__}:
-        return True
-
-    raise CustomRuntimeError(
-        "When inheriting from BaseScaler, you must implement the kernel radius by either adding "
-        "the `kernel_radius` property or setting the class variable `_static_kernel_radius`.",
-        cls,
-    )
+def _is_base_scaler_abstract(cls: type[BaseScaler]) -> bool:
+    return cls in abstract_kernels or not hasattr(cls, "kernel_radius") or isabstract(cls)
 
 
 def _is_format_resolver(
@@ -198,7 +157,7 @@ def _is_format_resolver(
 
 
 def _resolve_video_spec_args(clip: vs.VideoNode, **kwargs: Any) -> dict[str, Any]:
-    if _is_format_resolver((fmt := kwargs.get("format"))):
+    if _is_format_resolver(fmt := kwargs.get("format")):
         kwargs["format"] = get_video_format(fmt(clip))
 
     spec_map: dict[str, type[PropEnum]] = {
@@ -215,7 +174,7 @@ def _resolve_video_spec_args(clip: vs.VideoNode, **kwargs: Any) -> dict[str, Any
     }
 
     for name, prop_enum in spec_map.items():
-        if callable((resolver := kwargs.get(name))):
+        if callable(resolver := kwargs.get(name)):
             kwargs[name] = prop_enum.from_param_with_fallback(resolver(clip))
 
     return kwargs
@@ -257,8 +216,8 @@ class BaseScalerMeta(VSObjectABCMeta):
 
         if TYPE_CHECKING:
 
-            def __init__[_BaseScalerT: BaseScaler, **P](
-                self, func: Callable[Concatenate[_BaseScalerT, P], R]
+            def __init__[BaseScalerT: BaseScaler, **P](
+                self, func: Callable[Concatenate[BaseScalerT, P], R]
             ) -> None: ...
 
         def __set__(self, instance: None, value: Any) -> NoReturn:
@@ -360,9 +319,18 @@ class BaseScaler(VSObjectABC, metaclass=BaseScalerMeta, abstract=True):
             """
             Create a new instance of the scaler, validating kernel radius if applicable.
             """
-            if _check_kernel_radius(cls):
+            if not _is_base_scaler_abstract(cls):
                 return super().__new__(cls)
 
+            if cls in abstract_kernels:
+                raise CustomRuntimeError(f"Can't instantiate abstract class {cls.__name__}.", cls)
+
+            raise CustomRuntimeError(
+                "When inheriting from BaseScaler, you must implement the kernel radius by either adding "
+                "the `kernel_radius` property or setting the class variable `_static_kernel_radius`.",
+                cls,
+            )
+
     def __init__(self, **kwargs: Any) -> None:
         """
         Initialize the scaler with optional keyword arguments.
@@ -483,6 +451,12 @@ class BaseScaler(VSObjectABC, metaclass=BaseScalerMeta, abstract=True):
         """
         return self._pretty_string()
 
+    @classproperty
+    @classmethod
+    def is_abstract(cls) -> bool:
+        """Return True if this class can't be instantiated."""
+        return _is_base_scaler_abstract(cls)
+
     @classproperty.cached
     @classmethod
     def implemented_funcs(cls) -> frozenset[str]:
@@ -538,7 +512,11 @@ class Scaler(BaseScaler):
         """
         width, height = self._wh_norm(clip, width, height)
 
-        return self.scale_function(clip, **_norm_props_enums(self.get_scale_args(clip, shift, width, height, **kwargs)))
+        scale_args = _norm_props_enums(self.get_scale_args(clip, shift, width, height, **kwargs))
+
+        logger.debug("%s: Passing clip: %r; arguments: %s", self.scale, clip, scale_args)
+
+        return self.scale_function(clip, **scale_args)
 
     def supersample(
         self, clip: vs.VideoNode, rfactor: float = 2.0, shift: tuple[TopShift, LeftShift] = (0, 0), **kwargs: Any
@@ -642,9 +620,11 @@ class Descaler(BaseScaler):
         """
         width, height = self._wh_norm(clip, width, height)
 
-        return self.descale_function(
-            clip, **_norm_props_enums(self.get_descale_args(clip, shift, width, height, **kwargs))
-        )
+        descale_args = _norm_props_enums(self.get_descale_args(clip, shift, width, height, **kwargs))
+
+        logger.debug("%s: Passing clip: %r; arguments: %s", self.descale, clip, descale_args)
+
+        return self.descale_function(clip, **descale_args)
 
     def rescale(
         self,
@@ -672,9 +652,11 @@ class Descaler(BaseScaler):
         """
         width, height = self._wh_norm(clip, width, height)
 
-        return self.rescale_function(
-            clip, **_norm_props_enums(self.get_rescale_args(clip, shift, width, height, **kwargs))
-        )
+        rescale_args = _norm_props_enums(self.get_rescale_args(clip, shift, width, height, **kwargs))
+
+        logger.debug("%s: Passing clip: %r; arguments: %s", self.rescale, clip, rescale_args)
+
+        return self.rescale_function(clip, **rescale_args)
 
     def get_descale_args(
         self,
@@ -774,15 +756,17 @@ class Resampler(BaseScaler):
         Returns:
             The resampled clip.
         """
-        return self.resample_function(
-            clip,
-            **_norm_props_enums(
-                self.get_resample_args(
-                    clip, format, matrix, matrix_in, transfer, transfer_in, primaries, primaries_in, **kwargs
-                )
-            ),
+
+        resample_args = _norm_props_enums(
+            self.get_resample_args(
+                clip, format, matrix, matrix_in, transfer, transfer_in, primaries, primaries_in, **kwargs
+            )
         )
 
+        logger.debug("%s: Passing clip: %r; arguments: %s", self.resample, clip, resample_args)
+
+        return self.resample_function(clip, **resample_args)
+
     def get_resample_args(
         self,
         clip: vs.VideoNode,
@@ -820,7 +804,7 @@ class Resampler(BaseScaler):
             clip,
             **(
                 {
-                    "format": get_video_format(format).id,
+                    "format": get_video_format(format),
                     "matrix": Matrix.from_param_with_fallback(matrix),
                     "matrix_in": Matrix.from_param_with_fallback(matrix_in),
                     "transfer": Transfer.from_param_with_fallback(transfer),
@@ -1071,7 +1055,7 @@ class Kernel(Scaler, Descaler, Resampler):
             Dictionary of keyword arguments for the resample function.
         """
         return {
-            "format": get_video_format(format).id,
+            "format": get_video_format(format),
             "matrix": Matrix.from_param_with_fallback(matrix),
             "matrix_in": Matrix.from_param_with_fallback(matrix_in),
             "transfer": Transfer.from_param_with_fallback(transfer),
@@ -1107,8 +1091,11 @@ class Bobber(BaseScaler):
             The bobbed clip.
         """
         clip_fieldbased = FieldBased.from_param_or_video(tff, clip, True, self.__class__)
+        bob_args = self.get_bob_args(clip, tff=clip_fieldbased.is_tff, **kwargs)
 
-        return self.bob_function(clip, **self.get_bob_args(clip, tff=clip_fieldbased.is_tff, **kwargs))
+        logger.debug("%s: Passing clip: %r; arguments: %s", self.bob, clip, bob_args)
+
+        return self.bob_function(clip, **bob_args)
 
     def deinterlace(
         self, clip: vs.VideoNode, *, tff: FieldBasedLike | bool | None = None, double_rate: bool = True, **kwargs: Any
