@@ -5,9 +5,10 @@ This module defines core abstract classes for building edge detection and ridge
 from __future__ import annotations
 
 from abc import ABC, abstractmethod
+from collections.abc import Sequence
 from enum import IntFlag, auto
 from inspect import isabstract
-from typing import TYPE_CHECKING, Any, ClassVar, Self, Sequence
+from typing import TYPE_CHECKING, Any, ClassVar, Self
 
 from jetpytools import FuncExcept, get_subclasses, inject_kwargs_params, inject_self, to_arr
 
@@ -31,7 +32,6 @@ from ..exceptions import UnknownEdgeDetectError, UnknownRidgeDetectError, _Unkno
 __all__ = [
     "EdgeDetect",
     "EdgeDetectLike",
-    "EdgeDetectT",
     "EdgeMasksEdgeDetect",
     "EuclideanDistance",
     "MagDirection",
@@ -41,7 +41,6 @@ __all__ = [
     "Max",
     "RidgeDetect",
     "RidgeDetectLike",
-    "RidgeDetectT",
     "SingleMatrix",
     "get_all_edge_detects",
     "get_all_ridge_detect",
@@ -104,12 +103,12 @@ class MagDirection(IntFlag):
         return [matrix for flag, matrix in zip(primary_flags, matrices) if self & flag]
 
 
-def _base_from_param[_EdgeDetectT: EdgeDetect](
-    cls: type[_EdgeDetectT],
-    value: str | type[_EdgeDetectT] | _EdgeDetectT | None,
+def _base_from_param[EdgeDetectT: EdgeDetect](
+    cls: type[EdgeDetectT],
+    value: str | type[EdgeDetectT] | EdgeDetectT | None,
     exception_cls: type[_UnknownMaskDetectError],
     func_except: FuncExcept | None = None,
-) -> type[_EdgeDetectT]:
+) -> type[EdgeDetectT]:
     # If value is an instance returns the class
     if isinstance(value, cls):
         return value.__class__
@@ -133,11 +132,11 @@ def _base_from_param[_EdgeDetectT: EdgeDetect](
     raise exception_cls(func_except or cls.from_param, str(value))
 
 
-def _base_ensure_obj[_EdgeDetectT: EdgeDetect](
-    cls: type[_EdgeDetectT],
-    value: str | type[_EdgeDetectT] | _EdgeDetectT | None,
+def _base_ensure_obj[EdgeDetectT: EdgeDetect](
+    cls: type[EdgeDetectT],
+    value: str | type[EdgeDetectT] | EdgeDetectT | None,
     func_except: FuncExcept | None = None,
-) -> _EdgeDetectT:
+) -> EdgeDetectT:
     if isinstance(value, cls):
         return value
 
@@ -289,7 +288,7 @@ class EdgeDetect(ABC):
             func=self.__class__,
             lthr=lthr,
             hthr=hthr,
-            clamp=["%s %s clamp" % c if any(c) else "" for c in clamp],
+            clamp=["{} {} clamp".format(*c) if any(c) else "" for c in clamp],
         )
 
         return self._finalize_mask(mask, None, None, False, planes)
@@ -311,36 +310,6 @@ class EdgeDetect(ABC):
         return clip
 
 
-class TCannyEdgeDetect(EdgeDetect):
-    """
-    Edge detection using VapourSynth's `tcanny` plugin.
-    """
-
-    _op: ClassVar[int]
-    _scale: ClassVar[float] = 1.0
-
-    def _compute_edge_mask(
-        self,
-        clip: vs.VideoNode,
-        *,
-        multi: float | Sequence[float] = 1.0,
-        planes: Planes = None,
-        **kwargs: Any,
-    ) -> vs.VideoNode:
-        tcanny_args = {"op": self._op, "planes": planes} | {"sigma": 0, "mode": 1} | kwargs
-
-        if not isinstance(multi, Sequence):
-            return clip.tcanny.TCanny(scale=self._scale * multi, **tcanny_args)
-
-        return norm_expr(
-            clip.tcanny.TCanny(scale=self._scale, **tcanny_args),
-            "x {multi} *",
-            planes,
-            func=self.__class__,
-            multi=[self._scale * m for m in multi],
-        )
-
-
 class MatrixEdgeDetect(EdgeDetect):
     """
     Edge detection based on convolution matrices.
@@ -699,12 +668,6 @@ This includes:
  - An instance of a `RidgeDetect`.
 """
 
-EdgeDetectT = EdgeDetectLike
-"""Deprecated alias of EdgeDetectLike."""
-
-RidgeDetectT = RidgeDetectLike
-"""Deprecated alias of RidgeDetectLike."""
-
 
 def get_all_edge_detects(
     clip: vs.VideoNode,
