@@ -1,9 +1,10 @@
 from __future__ import annotations
 
 from abc import abstractmethod
+from collections.abc import Mapping
 from dataclasses import InitVar, dataclass, field
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Mapping, Type
+from typing import TYPE_CHECKING, Any
 
 from jetpytools import CustomOverflowError, FileNotExistsError, FilePathType, fallback, iterate
 
@@ -12,7 +13,7 @@ from vskernels import Point
 from vsrgtools import box_blur, median_blur
 
 if TYPE_CHECKING:
-    from vssource import Indexer
+    from vssource import IndexerLike
 
 from vstools import (
     ColorRange,
@@ -66,12 +67,12 @@ class CustomMaskFromClipsAndRanges(VSObjectABC, GeneralMask):
     clips: list[vs.VideoNode] = field(init=False)
 
     processing: VSFunctionNoArgs = field(default=core.lazy.std.BinarizeMask, kw_only=True)
-    idx: InitVar[Indexer | Type[Indexer] | None] = field(default=None, kw_only=True)
+    idx: InitVar[IndexerLike | None] = field(default=None, kw_only=True)
 
-    def __post_init__(self, idx: Indexer | Type[Indexer] | None) -> None:
-        from vssource import IMWRI
+    def __post_init__(self, idx: IndexerLike | None) -> None:
+        from vssource import BestSource, Indexer
 
-        self._idx = idx if idx else IMWRI
+        self._idx = Indexer.ensure_obj(idx, self.__class__) if idx else BestSource
 
     def get_mask(self, ref: vs.VideoNode, /, *args: Any, **kwargs: Any) -> vs.VideoNode:
         """
@@ -86,7 +87,7 @@ class CustomMaskFromClipsAndRanges(VSObjectABC, GeneralMask):
         """
         mask = vs.core.std.BlankClip(
             ref,
-            format=ref.format.replace(color_family=vs.GRAY, subsampling_h=0, subsampling_w=0).id,
+            format=ref.format.replace(color_family=vs.GRAY, subsampling_h=0, subsampling_w=0),
             keep=True,
             color=0,
         )
@@ -116,7 +117,7 @@ class CustomMaskFromFolder(CustomMaskFromClipsAndRanges):
 
     folder_path: FilePathType
 
-    def __post_init__(self, idx: Indexer | Type[Indexer] | None) -> None:
+    def __post_init__(self, idx: IndexerLike | None) -> None:
         super().__post_init__(idx)
         if not (folder_path := Path(str(self.folder_path))).is_dir():
             raise FileNotExistsError('"folder_path" must be an existing path directory!', self.get_mask)
@@ -141,7 +142,7 @@ class CustomMaskFromRanges(CustomMaskFromClipsAndRanges):
 
     ranges: Mapping[FilePathType, FrameRangeN | FrameRangesN]
 
-    def __post_init__(self, idx: Indexer | Type[Indexer] | None) -> None:
+    def __post_init__(self, idx: IndexerLike | None) -> None:
         self.clips = [self._idx.source(str(file), bits=-1) for file in self.ranges]
 
     def frame_ranges(self, clip: vs.VideoNode) -> list[list[tuple[int, int]]]:
@@ -315,7 +316,7 @@ class HardsubSign(HardsubMask):
     @limiter(mask=True)
     def _mask(self, clip: vs.VideoNode, ref: vs.VideoNode, **kwargs: Any) -> vs.VideoNode:
         hsmf = norm_expr([clip, ref], "x y - abs", func=self.__class__)
-        hsmf = core.resize.Bilinear(hsmf, format=clip.format.replace(subsampling_w=0, subsampling_h=0).id)
+        hsmf = core.resize.Bilinear(hsmf, format=clip.format.replace(subsampling_w=0, subsampling_h=0))
 
         hsmf = ExprOp.MAX(hsmf, split_planes=True)
 
@@ -503,7 +504,7 @@ def diff_hardsub_mask(a: vs.VideoNode, b: vs.VideoNode, **kwargs: Any) -> vs.Vid
 @limiter(mask=True)
 def get_all_sign_masks(hrdsb: vs.VideoNode, ref: vs.VideoNode, signs: list[HardsubMask]) -> vs.VideoNode:
     mask = core.std.BlankClip(
-        ref, format=ref.format.replace(color_family=vs.GRAY, subsampling_w=0, subsampling_h=0).id, keep=True
+        ref, format=ref.format.replace(color_family=vs.GRAY, subsampling_w=0, subsampling_h=0), keep=True
     )
 
     for sign in signs:
