@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Callable, Union
+from collections.abc import Callable
 
 from jetpytools import CustomEnum
 
@@ -9,7 +9,7 @@ from vstools import vs
 from .abstract import GeneralMask
 from .edge._abstract import EdgeDetectLike, RidgeDetectLike
 
-__all__ = ["Coordinates", "GenericMaskT", "MaskLike", "XxpandMode"]
+__all__ = ["Coordinates", "MaskLike", "XxpandMode"]
 
 
 class XxpandMode(CustomEnum):
@@ -52,15 +52,12 @@ class Coordinates(tuple[int, ...], CustomEnum):
         return cls.RECTANGLE
 
 
-MaskLike = Union[
-    vs.VideoNode,
-    Callable[[vs.VideoNode, vs.VideoNode], vs.VideoNode],
-    EdgeDetectLike,
-    RidgeDetectLike,
-    GeneralMask,
-    str,
-]
+MaskLike = (
+    vs.VideoNode
+    | Callable[[vs.VideoNode, vs.VideoNode], vs.VideoNode]
+    | EdgeDetectLike
+    | RidgeDetectLike
+    | GeneralMask
+    | str
+)
 """Type alias for anything that can resolve to a mask."""
-
-GenericMaskT = MaskLike
-"""Deprecated alias of MaskLike"""
