@@ -1,7 +1,8 @@
 from __future__ import annotations
 
+from collections.abc import Iterable, Sequence
 from enum import auto
-from typing import Any, Iterable, Literal, Sequence, SupportsIndex, overload
+from typing import Any, Literal, SupportsIndex, overload
 
 from jetpytools import CustomEnum, CustomValueError, FuncExcept, SupportsString, normalize_seq
 
@@ -180,7 +181,6 @@ class MeanMode(CustomEnum):
 
         Args:
             n: Object from which to infer the variables.
-            eps: Small constant to avoid division by zero. Defaults to 1e-7.
             **kwargs: Additional keyword arguments for certain modes.
 
                    - p (float): Exponent for `LEHMER` mode. Defaults to 3.
