@@ -6,9 +6,10 @@ originally written for [Irozuku Sekai no Ashita kara](https://myanimelist.net/an
 """
 
 from abc import abstractmethod
+from collections.abc import Sequence
 from dataclasses import dataclass, field
 from math import sqrt
-from typing import TYPE_CHECKING, Any, Literal, NamedTuple, Protocol, Sequence
+from typing import TYPE_CHECKING, Any, Literal, NamedTuple, Protocol
 
 from jetpytools import CustomRuntimeError, CustomValueError, FuncExcept, MismatchRefError, cachedproperty, clamp
 
@@ -17,7 +18,6 @@ from vsjetpack import require_jet_dependency
 from vskernels import LeftShift, TopShift
 from vstools import (
     ChromaLocation,
-    ConstantFormatVideoNode,
     ConvMode,
     FormatsRefClipMismatchError,
     ResolutionsRefClipMismatchError,
@@ -452,7 +452,7 @@ class ChromaReconstruct(VSObjectABC):
     chroma_bases: Sequence[vs.VideoNode]
     """The chroma base planes."""
 
-    clip_src: ConstantFormatVideoNode
+    clip_src: vs.VideoNode
     """The original source clip."""
 
     chroma_loc: ChromaLocation = field(init=False)
