@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Callable, Sequence
+from collections.abc import Callable, Sequence
 
 from jetpytools import CustomIntEnum, CustomStrEnum, KwargsNotNone
 
