@@ -1,12 +1,22 @@
 from __future__ import annotations
 
+from collections.abc import Callable, Iterable
 from functools import wraps
-from typing import Any, Callable, Iterable
+from typing import Any
 
 from jetpytools import cachedproperty
 
 from vsexprtools import ExprToken, norm_expr
-from vskernels import Bilinear, BorderHandling, ComplexKernel, ComplexKernelLike, Hermite, Scaler, ScalerLike
+from vskernels import (
+    Bilinear,
+    BorderHandling,
+    ComplexKernel,
+    ComplexKernelLike,
+    Hermite,
+    SampleGridModel,
+    Scaler,
+    ScalerLike,
+)
 from vskernels.types import LeftShift, TopShift
 from vsmasktools import Kirsch, based_diff_mask, region_rel_mask, stabilize_mask
 from vstools import (
@@ -52,7 +62,7 @@ class RescaleBase(VSObjectABC):
         upscaler: ScalerLike = ArtCNN,
         downscaler: ScalerLike = Hermite(linear=True),
         field_based: FieldBasedLike | bool | None = None,
-        border_handling: int | BorderHandling = BorderHandling.MIRROR,
+        border_handling: int = BorderHandling.MIRROR,
         **kwargs: Any,
     ) -> None:
         self._clipy, *chroma = split(clip)
@@ -70,11 +80,11 @@ class RescaleBase(VSObjectABC):
         self.__add_props = kwargs.get("_add_props")
 
     @staticmethod
-    def _apply_field_based[_RescaleT: RescaleBase](
-        function: Callable[[_RescaleT, vs.VideoNode], vs.VideoNode],
-    ) -> Callable[[_RescaleT, vs.VideoNode], vs.VideoNode]:
+    def _apply_field_based[RescaleT: RescaleBase](
+        function: Callable[[RescaleT, vs.VideoNode], vs.VideoNode],
+    ) -> Callable[[RescaleT, vs.VideoNode], vs.VideoNode]:
         @wraps(function)
-        def wrap(self: _RescaleT, clip: vs.VideoNode) -> vs.VideoNode:
+        def wrap(self: RescaleT, clip: vs.VideoNode) -> vs.VideoNode:
             if self._field_based:
                 clip = self._field_based.apply(clip)
                 clip = function(self, clip)
@@ -85,11 +95,11 @@ class RescaleBase(VSObjectABC):
         return wrap
 
     @staticmethod
-    def _add_props[_RescaleT: RescaleBase](
-        function: Callable[[_RescaleT, vs.VideoNode], vs.VideoNode],
-    ) -> Callable[[_RescaleT, vs.VideoNode], vs.VideoNode]:
+    def _add_props[RescaleT: RescaleBase](
+        function: Callable[[RescaleT, vs.VideoNode], vs.VideoNode],
+    ) -> Callable[[RescaleT, vs.VideoNode], vs.VideoNode]:
         @wraps(function)
-        def wrap(self: _RescaleT, clip: vs.VideoNode) -> vs.VideoNode:
+        def wrap(self: RescaleT, clip: vs.VideoNode) -> vs.VideoNode:
             if not self.__add_props:
                 return function(self, clip)
 
@@ -271,10 +281,11 @@ class Rescale(RescaleBase):
         width: int | float | None = None,  # noqa: PYI041
         base_height: int | None = None,
         base_width: int | None = None,
-        crop: tuple[LeftCrop, RightCrop, TopCrop, BottomCrop] = CropRel(),
+        crop: tuple[LeftCrop, RightCrop, TopCrop, BottomCrop] | None = None,
         shift: tuple[TopShift, LeftShift] = (0, 0),
         field_based: FieldBasedLike | bool | None = None,
-        border_handling: int | BorderHandling = BorderHandling.MIRROR,
+        border_handling: int = BorderHandling.MIRROR,
+        sample_grid_model: int = SampleGridModel.MATCH_EDGES,
         **kwargs: Any,
     ) -> None:
         """
@@ -305,15 +316,16 @@ class Rescale(RescaleBase):
                      where the outermost row was extended infinitely far.
 
                 Defaults to ``0``.
+            sample_grid_model: Model used to align sampling grid.
         """
         self._line_mask: vs.VideoNode | None = None
         self._credit_mask: vs.VideoNode | None = None
         self._ignore_mask: vs.VideoNode | None = None
-        self._crop = crop
+        self._crop = crop or CropRel()
         self._pre = clip
 
         self.descale_args = ScalingArgs.from_args(
-            clip, height, width, base_height, base_width, shift[0], shift[1], crop, mode="hw"
+            clip, height, width, base_height, base_width, shift[0], shift[1], crop, sample_grid_model, mode="hw"
         )
 
         super().__init__(clip, kernel, upscaler, downscaler, field_based, border_handling, **kwargs)
