@@ -1,11 +1,11 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Literal
+from typing import Any, Literal
 
-from jetpytools import CustomValueError, normalize_seq
-from typing_extensions import TypeVar
+from jetpytools import CustomOverflowError, CustomValueError, normalize_seq
 
 from vsexprtools import ExprOp, combine, norm_expr
+from vsjetpack import TypeVar
 from vskernels import (
     Catrom,
     ComplexScaler,
@@ -20,15 +20,7 @@ from vskernels import (
 )
 from vsmasktools import ringing_mask
 from vsrgtools.rgtools import Repair
-from vstools import (
-    ChromaLocation,
-    ConstantFormatVideoNode,
-    CustomOverflowError,
-    check_ref_clip,
-    check_variable,
-    scale_delta,
-    vs,
-)
+from vstools import ChromaLocation, check_ref_clip, check_variable_resolution, scale_delta, vs
 
 from .generic import GenericScaler
 
@@ -107,7 +99,7 @@ class ClampScaler(GenericScaler):
         height: int | None = None,
         shift: tuple[float, float] = (0, 0),
         **kwargs: Any,
-    ) -> ConstantFormatVideoNode:
+    ) -> vs.VideoNode:
         width, height = self._wh_norm(clip, width, height)
 
         base = self.base_scaler.scale(clip, width, height, shift, **kwargs)
@@ -122,12 +114,6 @@ class ClampScaler(GenericScaler):
 
         check_ref_clip(base, smooth)
 
-        if TYPE_CHECKING:
-            from vstools import check_variable_format
-
-            assert check_variable_format(base, self.__class__)
-            assert check_variable_format(smooth, self.__class__)
-
         merge_weight = self.strength / 100
 
         if self.limit is True:
@@ -167,9 +153,7 @@ class ClampScaler(GenericScaler):
 _ComplexScalerWithLanczosDefaultT = TypeVar("_ComplexScalerWithLanczosDefaultT", bound=ComplexScaler, default=Lanczos)
 
 
-class ComplexSuperSamplerProcess(
-    MixedScalerProcess[_ComplexScalerWithLanczosDefaultT, Point], ComplexScaler, partial_abstract=True
-):
+class ComplexSuperSamplerProcess(MixedScalerProcess[_ComplexScalerWithLanczosDefaultT, Point], ComplexScaler):
     """
     A utility ComplexScaler class that applies a given function to a supersampled clip,
     then downsamples it back using Point.
@@ -191,7 +175,7 @@ class ComplexSuperSamplerProcess(
         chroma placement relative to luma is required.
     """
 
-    _default_scaler = Lanczos
+    default_scaler = Lanczos
 
     def scale(
         self,
@@ -200,8 +184,8 @@ class ComplexSuperSamplerProcess(
         height: int | None = None,
         shift: tuple[TopShift | list[TopShift], LeftShift | list[LeftShift]] = (0, 0),
         **kwargs: Any,
-    ) -> vs.VideoNode | ConstantFormatVideoNode:
-        assert check_variable(clip, self.scale)
+    ) -> vs.VideoNode:
+        assert check_variable_resolution(clip, self.scale)
 
         width, height = self._wh_norm(clip, width, height)
         rfactor_w, rfactor_h = (width / clip.width), (height / clip.height)
