@@ -1,9 +1,9 @@
 from __future__ import annotations
 
 import warnings
+from collections.abc import Sequence
 from copy import deepcopy
 from itertools import count
-from typing import Sequence
 
 from jetpytools import CustomRuntimeError
 
