@@ -1,6 +1,7 @@
 from __future__ import annotations
 
-from typing import Any, Mapping
+from collections.abc import Mapping
+from typing import Any
 
 from jetpytools import FuncExcept
 
@@ -12,16 +13,12 @@ from .base import PropEnum, _base_from_video
 __all__ = [
     "ColorRange",
     "ColorRangeLike",
-    "ColorRangeT",  # Deprecated alias
     "Matrix",
     "MatrixLike",
-    "MatrixT",  # Deprecated alias
     "Primaries",
     "PrimariesLike",
-    "PrimariesT",  # Deprecated alias
     "Transfer",
     "TransferLike",
-    "TransferT",  # Deprecated alias
 ]
 
 
@@ -742,18 +739,6 @@ type PrimariesLike = int | vs.ColorPrimaries | Primaries | HoldsPropValue
 type ColorRangeLike = int | vs.ColorRange | ColorRange | HoldsPropValue
 """Type alias for values that can be used to initialize a [ColorRange][vstools.ColorRange]."""
 
-MatrixT = MatrixLike
-"""Deprecated alias of MatrixLike"""
-
-TransferT = TransferLike
-"""Deprecated alias of TransferLike"""
-
-PrimariesT = PrimariesLike
-"""Deprecated alias of PrimariesLike"""
-
-ColorRangeT = ColorRangeLike
-"""Deprecated alias of ColorRangeLike"""
-
 
 def _norm_props_enums(kwargs: dict[str, Any]) -> dict[str, Any]:
     return {key: (value.value_zimg if isinstance(value, ColorRange) else value) for key, value in kwargs.items()}
