@@ -1,9 +1,10 @@
 from __future__ import annotations
 
 from abc import abstractmethod
+from collections.abc import Callable
 from functools import partial, wraps
 from inspect import signature
-from typing import Any, Callable, Literal, overload
+from typing import Any, Literal, SupportsInt, overload
 
 from jetpytools import CustomValueError, FuncExcept, StrictRange
 
@@ -52,7 +53,7 @@ class ProcessVariableClip[T](DynamicClipsCache[T]):
         self,
         clip: vs.VideoNode,
         out_dim: tuple[int, int] | Literal[False] | None = None,
-        out_fmt: int | vs.VideoFormat | Literal[False] | None = None,
+        out_fmt: SupportsInt | Literal[False] | None = None,
         cache_size: int = 10,
     ) -> None:
         """
@@ -83,7 +84,7 @@ class ProcessVariableClip[T](DynamicClipsCache[T]):
         if out_fmt is False:
             bk_args.update(format=vs.GRAY8, varformat=True)
         else:
-            bk_args.update(format=out_fmt if isinstance(out_fmt, int) else out_fmt.id)
+            bk_args.update(format=int(out_fmt))
 
         super().__init__(cache_size)
 
@@ -208,7 +209,7 @@ class ProcessVariableFormatClip(ProcessVariableClip[vs.VideoFormat]):
         return frame.format
 
     def normalize(self, clip: vs.VideoNode, cast_to: vs.VideoFormat) -> vs.VideoNode:
-        normalized = vs.core.resize.Point(vs.core.std.RemoveFrameProps(clip), format=cast_to.id)
+        normalized = vs.core.resize.Point(vs.core.std.RemoveFrameProps(clip), format=cast_to)
         return vs.core.std.CopyFrameProps(normalized, clip)
 
 
@@ -224,7 +225,7 @@ class ProcessVariableResFormatClip(ProcessVariableClip[tuple[int, int, vs.VideoF
     def normalize(self, clip: vs.VideoNode, cast_to: tuple[int, int, vs.VideoFormat]) -> vs.VideoNode:
         w, h, fmt = cast_to
 
-        normalized = vs.core.resize.Point(vs.core.std.RemoveFrameProps(clip), w, h, fmt.id)
+        normalized = vs.core.resize.Point(vs.core.std.RemoveFrameProps(clip), w, h, fmt)
 
         return vs.core.std.CopyFrameProps(normalized, clip)
 
@@ -233,7 +234,7 @@ def finalize_clip(
     clip: vs.VideoNode,
     bits: VideoFormatLike | HoldsVideoFormat | int | None = 10,
     clamp_tv_range: bool = False,
-    dither_type: DitherType = DitherType.AUTO,
+    dither_type: DitherType = DitherType.RANDOM,
     *,
     func: FuncExcept | None = None,
 ) -> vs.VideoNode:
@@ -266,7 +267,7 @@ def finalize_output[**P](
     *,
     bits: int | None = 10,
     clamp_tv_range: bool = False,
-    dither_type: DitherType = DitherType.AUTO,
+    dither_type: DitherType = DitherType.RANDOM,
     func: FuncExcept | None = None,
 ) -> Callable[P, vs.VideoNode]: ...
 
@@ -276,7 +277,7 @@ def finalize_output[**P](
     *,
     bits: int | None = 10,
     clamp_tv_range: bool = False,
-    dither_type: DitherType = DitherType.AUTO,
+    dither_type: DitherType = DitherType.RANDOM,
     func: FuncExcept | None = None,
 ) -> Callable[[Callable[P, vs.VideoNode]], Callable[P, vs.VideoNode]]: ...
 
@@ -287,7 +288,7 @@ def finalize_output[**P](
     *,
     bits: int | None = 10,
     clamp_tv_range: bool = False,
-    dither_type: DitherType = DitherType.AUTO,
+    dither_type: DitherType = DitherType.RANDOM,
     func: FuncExcept | None = None,
 ) -> Callable[P, vs.VideoNode] | Callable[[Callable[P, vs.VideoNode]], Callable[P, vs.VideoNode]]:
     """
@@ -304,6 +305,34 @@ def finalize_output[**P](
     return _wrapper
 
 
+@overload
+def initialize_clip(
+    clip: vs.VideoNode,
+    bits: int | None = None,
+    matrix: MatrixLike | None = None,
+    transfer: TransferLike | None = None,
+    primaries: PrimariesLike | None = None,
+    chroma_location: ChromaLocationLike | None = None,
+    color_range: ColorRangeLike | None = None,
+    field_based: FieldBasedLike | None = None,
+    strict: Literal[False] = False,
+    dither_type: DitherType = DitherType.RANDOM,
+    *,
+    func: FuncExcept | None = None,
+) -> vs.VideoNode: ...
+
+
+@overload
+def initialize_clip(
+    clip: vs.VideoNode,
+    bits: int | None = None,
+    *,
+    strict: Literal[True],
+    dither_type: DitherType = DitherType.RANDOM,
+    func: FuncExcept | None = None,
+) -> vs.VideoNode: ...
+
+
 def initialize_clip(
     clip: vs.VideoNode,
     bits: int | None = None,
@@ -314,15 +343,26 @@ def initialize_clip(
     color_range: ColorRangeLike | None = None,
     field_based: FieldBasedLike | None = None,
     strict: bool = False,
-    dither_type: DitherType = DitherType.AUTO,
+    dither_type: DitherType = DitherType.RANDOM,
     *,
     func: FuncExcept | None = None,
 ) -> vs.VideoNode:
     """
-    Initialize a clip with default props.
+    Initialize a clip with default properties or ensure their existence.
 
     It is HIGHLY recommended to always use this function at the beginning of your scripts!
 
+    This function operates in two modes defined by the `strict` parameter:
+
+    - `strict=False`: Sets missing properties. It attempts to read existing props.
+
+          * If missing, it uses the manually provided arguments.
+          * If those are None, it guesses based on resolution or video format.
+
+    - `strict=True`: Validates that the input clip has all relevant frame properties
+     (Matrix, Transfer, Primaries, ChromaLocation, ColorRange, FieldBased) already set.
+     If any are missing, it raises an exception. Manual property arguments are not accepted.
+
     Args:
         clip: Clip to initialize.
         bits: Bits to dither to.
@@ -331,25 +371,19 @@ def initialize_clip(
                - If None, 16 if bit depth is lower than it, else leave untouched.
                - If positive integer, dither to that bitdepth.
 
-        matrix: Matrix property to set. If None, tries to get the Matrix from existing props. If no props are set or
-            Matrix=2, guess from the video resolution.
-        transfer: Transfer property to set. If None, tries to get the Transfer from existing props. If no props are set
-            or Transfer=2, guess from the video resolution.
-        primaries: Primaries property to set. If None, tries to get the Primaries from existing props. If no props are
-            set or Primaries=2, guess from the video resolution.
-        chroma_location: ChromaLocation prop to set. If None, tries to get the ChromaLocation from existing props. If no
-            props are set, guess from the video resolution.
-        color_range: ColorRange prop to set. If None, tries to get the ColorRange from existing props. If no props are
-            set, assume Limited Range.
-        field_based: FieldBased prop to set. If None, tries to get the FieldBased from existing props. If no props are
-            set, assume PROGRESSIVE.
-        strict: Whether to be strict about existing properties. If True, throws an exception if certain frame properties
-            are not found.
+        matrix: Matrix property to set. Ignored if `strict=True`.
+        transfer: Transfer property to set. Ignored if `strict=True`.
+        primaries: Primaries property to set. Ignored if `strict=True`.
+        chroma_location: ChromaLocation prop to set. Ignored if `strict=True`.
+        color_range: ColorRange prop to set. Ignored if `strict=True`.
+        field_based: FieldBased prop to set. Ignored if `strict=True`.
+        strict: Whether to strictly validate existing properties.
+            If True, arguments for specific properties (e.g. `matrix`) are not accepted.
         dither_type: Dithering used for the bitdepth conversion.
         func: Function returned for custom error handling. This should only be set by VS package developers.
 
     Returns:
-        Clip with relevant frame properties set, and optionally dithered up to 16 bits by default.
+        Clip with relevant frame properties set/validated, and optionally dithered to 16-bit (or target `bits`).
     """
     func = func or initialize_clip
 
@@ -393,7 +427,7 @@ def initialize_input[**P](
     color_range: ColorRangeLike | None = None,
     field_based: FieldBasedLike | None = None,
     strict: bool = False,
-    dither_type: DitherType = DitherType.AUTO,
+    dither_type: DitherType = DitherType.RANDOM,
     func: FuncExcept | None = None,
 ) -> Callable[P, vs.VideoNode]: ...
 
@@ -408,7 +442,7 @@ def initialize_input[**P](
     chroma_location: ChromaLocationLike | None = None,
     color_range: ColorRangeLike | None = None,
     field_based: FieldBasedLike | None = None,
-    dither_type: DitherType = DitherType.AUTO,
+    dither_type: DitherType = DitherType.RANDOM,
     func: FuncExcept | None = None,
 ) -> Callable[[Callable[P, vs.VideoNode]], Callable[P, vs.VideoNode]]: ...
 
@@ -425,7 +459,7 @@ def initialize_input[**P](
     color_range: ColorRangeLike | None = None,
     field_based: FieldBasedLike | None = None,
     strict: bool = False,
-    dither_type: DitherType = DitherType.AUTO,
+    dither_type: DitherType = DitherType.RANDOM,
     func: FuncExcept | None = None,
 ) -> Callable[P, vs.VideoNode] | Callable[[Callable[P, vs.VideoNode]], Callable[P, vs.VideoNode]]:
     """
