@@ -1,18 +1,31 @@
 from __future__ import annotations
 
 import operator
+from collections.abc import Callable, Iterable, Mapping, Sequence
+from enum import EnumMeta
 from functools import partial, reduce, wraps
 from types import NoneType
-from typing import Any, Callable, Iterable, Mapping, Self, Sequence, SupportsIndex, Union, overload
+from typing import Any, Literal, Self, SupportsIndex, overload
 from weakref import WeakValueDictionary
 
-from jetpytools import CustomIndexError, CustomStrEnum, CustomTypeError, FuncExcept, normalize_seq, to_arr
+from jetpytools import (
+    CustomIndexError,
+    CustomNotImplementedError,
+    CustomStrEnum,
+    CustomTypeError,
+    FuncExcept,
+    cachedproperty,
+    normalize_seq,
+    to_arr,
+)
 
-from ..enums import ColorRange, ColorRangeLike
+from vsjetpack import deprecated
+
+from ..enums import ColorRange, ColorRangeLike, Matrix
 from ..exceptions import ClipLengthError, UnsupportedColorFamilyError
 from ..types import HoldsVideoFormat, Planes, VideoFormatLike, VideoNodeIterable
-from ..utils import flatten, get_depth, get_video_format
-from ..vs_proxy import vs
+from ..utils import flatten, get_depth, get_lowest_value, get_peak_value, get_video_format
+from ..vs_proxy import core, vs
 
 __all__ = [
     "EXPR_VARS",
@@ -33,6 +46,7 @@ __all__ = [
     "plane",
     "split",
     "stack_clips",
+    "stack_planes",
 ]
 
 
@@ -69,41 +83,45 @@ Variables to access clips in Expr.
 """
 
 
-class DitherType(CustomStrEnum):
+class _EnumDeprecationWarning(DeprecationWarning): ...
+
+
+class _DitherTypeMeta(EnumMeta):
+    @property
+    @deprecated(
+        '"AUTO" member is deprecated and will be removed in a future version. Please use RANDOM instead',
+        category=_EnumDeprecationWarning,
+    )
+    def AUTO(cls) -> Literal[DitherType.RANDOM]:  # noqa: N802
+        return DitherType.RANDOM
+
+
+class DitherType(CustomStrEnum, metaclass=_DitherTypeMeta):
     """
     Enum for `zimg_dither_type_e` and fmtc `dmode`.
     """
 
-    AUTO = "auto"
-    """
-    Choose automatically.
-    """
-
-    NONE = "none"
+    NONE = "none", 1
     """
     Round to nearest.
     """
 
-    ORDERED = "ordered"
+    ORDERED = "ordered", 0
     """
     Bayer patterned dither.
     """
 
-    RANDOM = "random"
+    RANDOM = "random", 8
     """
     Pseudo-random noise of magnitude 0.5.
     """
 
-    ERROR_DIFFUSION = "error_diffusion"
+    ERROR_DIFFUSION = "error_diffusion", 6
     """
     Floyd-Steinberg error diffusion.
     """
 
-    ERROR_DIFFUSION_FMTC = "error_diffusion_fmtc", 6
-    """
-    Floyd-Steinberg error diffusion.
-    Modified for serpentine scan (avoids worm artifacts).
-    """
+    FLOYD_STEINBERG = ERROR_DIFFUSION
 
     SIERRA_2_4A = "sierra_2_4a", 3
     """
@@ -129,10 +147,7 @@ class DitherType(CustomStrEnum):
     Slow, available only for integer input at the moment. Avoids usual F-S artifacts.
     """
 
-    VOID = "void", 8
-    """
-    A way to generate blue-noise dither and has a much better visual aspect than ordered dithering.
-    """
+    VOID = RANDOM
 
     QUASIRANDOM = "quasirandom", 9
     """
@@ -140,9 +155,9 @@ class DitherType(CustomStrEnum):
     Good intermediary between void, cluster, and error diffusion algorithms.
     """
 
-    _fmtc_dmode: int | None
+    _fmtc_dmode: int
 
-    def __new__(cls, value: Any, fmtc_dmode: int | None = None) -> Self:
+    def __new__(cls, value: Any, fmtc_dmode: int) -> Self:
         obj = str.__new__(cls, value)
         obj._value_ = value
 
@@ -151,20 +166,21 @@ class DitherType(CustomStrEnum):
         return obj
 
     def apply(
-        self, clip: vs.VideoNode, out_fmt: vs.VideoFormat, range_in: ColorRange, range_out: ColorRange
+        self,
+        clip: vs.VideoNode,
+        out_fmt: vs.VideoFormat,
+        range_in: ColorRange,
+        range_out: ColorRange,
+        force_fmtc: bool,
     ) -> vs.VideoNode:
         """
         Apply the given DitherType to a clip.
         """
-        if self is DitherType.AUTO:
-            self = DitherType.VOID if DitherType.should_dither(clip, out_fmt, range_in, range_out) else DitherType.NONE
-
         fmt = get_video_format(clip)
-        clip = ColorRange.ensure_presence(clip, range_in)
 
-        if not self.is_fmtc():
+        if not (self.is_fmtc or force_fmtc):
             return clip.resize.Point(
-                format=out_fmt.id,
+                format=out_fmt,
                 dither_type=self.value.lower(),
                 range_in=range_in.value_zimg,
                 range=range_out.value_zimg,
@@ -172,7 +188,7 @@ class DitherType(CustomStrEnum):
 
         # Workaround because fmtc doesn't support FLOAT 16 input
         if fmt.sample_type is vs.FLOAT and fmt.bits_per_sample == 16:
-            clip = DitherType.NONE.apply(clip, fmt.replace(bits_per_sample=32), range_in, range_out)
+            clip = DitherType.NONE.apply(clip, fmt.replace(bits_per_sample=32), range_in, range_out, False)
 
         return clip.fmtc.bitdepth(
             dmode=self._fmtc_dmode,
@@ -181,11 +197,18 @@ class DitherType(CustomStrEnum):
             fulld=range_out is ColorRange.FULL,
         )
 
+    @cachedproperty
     def is_fmtc(self) -> bool:
         """
-        Whether the DitherType is applied through fmtc.
+        Whether the DitherType is exclusive to fmtc.
         """
-        return self._fmtc_dmode is not None
+        return self in (
+            DitherType.SIERRA_2_4A,
+            DitherType.STUCKI,
+            DitherType.ATKINSON,
+            DitherType.OSTROMOUKHOV,
+            DitherType.QUASIRANDOM,
+        )
 
     @overload
     @staticmethod
@@ -236,6 +259,7 @@ class DitherType(CustomStrEnum):
         """
 
     @staticmethod
+    @deprecated("should_dither is deprecated and will be removed in a future version.", category=DeprecationWarning)
     def should_dither(
         in_bits_or_fmt: int | VideoFormatLike | HoldsVideoFormat,
         out_bits_or_fmt: int | VideoFormatLike | HoldsVideoFormat,
@@ -308,13 +332,13 @@ def depth(
     *,
     range_in: ColorRangeLike | None = None,
     range_out: ColorRangeLike | None = None,
-    dither_type: str | DitherType = DitherType.AUTO,
+    dither_type: str | DitherType = DitherType.RANDOM,
+    force_fmtc: bool = False,
 ) -> vs.VideoNode:
     """
     A convenience bitdepth conversion function using only internal plugins if possible.
 
     This uses exclusively internal plugins except for specific dither_types.
-    To check whether your DitherType uses fmtc, use [DitherType.is_fmtc][vstools.DitherType.is_fmtc].
 
     Example:
         ```py
@@ -334,18 +358,14 @@ def depth(
         range_in: Input pixel range (defaults to input `clip`'s range).
         range_out: Output pixel range (defaults to input `clip`'s range).
         dither_type: Dithering algorithm. Allows overriding default dithering behavior.
-            See [DitherType][vstools.DitherType].
-
-            When integer output is desired but the conversion may produce fractional values,
-            defaults to [VOID][vstools.DitherType.VOID].
-
-            In other cases, defaults to no dither.
-
-            See [DitherType.should_dither][vstools.DitherType.should_dither] for more information.
+        force_fmtc: Force usage of fmtc to apply dithering.
 
     Returns:
         Converted clip with desired bit depth and sample type. `ColorFamily` will be same as input.
     """
+    if range_in is not None:
+        clip = ColorRange.ensure_presence(clip, range_in)
+
     in_fmt = get_video_format(clip)
     out_fmt = get_video_format(bitdepth or clip, sample_type=sample_type)
 
@@ -361,7 +381,7 @@ def depth(
 
     new_format = in_fmt.replace(bits_per_sample=out_fmt.bits_per_sample, sample_type=out_fmt.sample_type)
 
-    return DitherType.from_param(dither_type, depth).apply(clip, new_format, range_in, range_out)
+    return DitherType.from_param(dither_type, depth).apply(clip, new_format, range_in, range_out, force_fmtc)
 
 
 def expect_bits(clip: vs.VideoNode, /, expected_depth: int = 16, **kwargs: Any) -> tuple[vs.VideoNode, int]:
@@ -404,7 +424,7 @@ def frame2clip(frame: vs.VideoFrame) -> vs.VideoNode:
 
     if _f2c_cache.get(key, None) is None:
         _f2c_cache[key] = blank_clip = vs.core.std.BlankClip(
-            None, frame.width, frame.height, frame.format.id, 1, 1, 1, [0] * frame.format.num_planes, True
+            None, frame.width, frame.height, frame.format, 1, 1, 1, [0] * frame.format.num_planes, True
         )
     else:
         blank_clip = _f2c_cache[key]
@@ -868,6 +888,122 @@ def stack_clips(clips: Iterable[VideoNodeIterable]) -> vs.VideoNode:
     )
 
 
+@overload
+def stack_planes(
+    clip: vs.VideoNode,
+    shift_float_chroma: bool = True,
+    offset_chroma: Literal["min", "max", False] | float = False,
+    mode: Literal["h", "v"] = "h",
+    write_plane_name: Literal[False] = False,
+) -> vs.VideoNode: ...
+
+
+@overload
+def stack_planes(
+    clip: vs.VideoNode,
+    shift_float_chroma: bool = True,
+    offset_chroma: Literal["min", "max", False] | float = False,
+    mode: Literal["h", "v"] = "h",
+    write_plane_name: bool = ...,
+    alignment: int = 7,
+    scale: int = 1,
+) -> vs.VideoNode: ...
+
+
+def stack_planes(
+    clip: vs.VideoNode,
+    shift_float_chroma: bool = True,
+    offset_chroma: Literal["min", "max", False] | float = False,
+    mode: Literal["h", "v"] = "h",
+    write_plane_name: bool = False,
+    alignment: int = 7,
+    scale: int = 1,
+) -> vs.VideoNode:
+    """
+    Split a clip into its individual planes and stack them visually for inspection.
+
+    Args:
+        clip: Input clip to be split and visually stacked.
+        shift_float_chroma: If True, shift U and V by +0.5 when working in float YUV formats.
+        offset_chroma: Apply chroma plane offseting:
+
+               - "min": match luma minimum
+               - "max": match luma maximum
+               - float: add value directly
+               - False: no chroma offseting
+        mode: Stacking direction:
+
+               - "h": horizontal (default)
+               - "v": vertical
+        write_plane_name: If True, overlays the short plane name ("Y", "U", "V", "R", "G", ...) on each plane.
+        alignment: Text alignment for plane labels (only used if `write_plane_name=True`).
+        scale: Font scale for plane labels (only used if `write_plane_name=True`).
+
+    Returns:
+        A clip containing the stacked planes.
+    """
+    if clip.format.color_family is vs.GRAY:
+        return clip
+
+    if clip.format.sample_type is vs.FLOAT:
+        clip = depth(clip, 32)
+
+    if clip.format.color_family is vs.YUV:
+        if clip.format.sample_type is vs.FLOAT and shift_float_chroma:
+            clip = core.std.Expr(clip, ["", "x 0.5 +"])
+
+        def offset_uv_planes(value: float, plane_stats: str) -> list[vs.VideoNode]:
+            planes = split(clip)
+
+            if clip.format.sample_type is vs.FLOAT:
+                value += 0.5
+
+            planes[1:] = [
+                p.std.PlaneStats().akarin.Expr(f"x {value} x.PlaneStats{plane_stats} - +") for p in planes[1:]
+            ]
+            return planes
+
+        match offset_chroma:
+            case "min":
+                planes = offset_uv_planes(get_lowest_value(clip, True), "Min")
+            case "max":
+                planes = offset_uv_planes(get_peak_value(clip, True), "Max")
+            case False:
+                planes = split(clip)
+            case _:
+                planes = split(core.std.Expr(clip, ["", f"x {offset_chroma} +"]))
+    else:
+        planes = split(clip)
+
+    if write_plane_name:
+        planes = [c.text.Text(k, alignment, scale) for k, c in zip(clip.format.name, planes)]
+
+    org: VideoNodeIterable
+
+    dim = {"h": "h", "v": "w"}[mode]
+
+    match getattr(clip.format, f"subsampling_{dim}"):
+        case 2:
+            blank = planes[1].std.BlankClip(keep=True)
+            org = [planes[0], (blank, *planes[1:], blank)]
+        case 1:
+            org = [planes[0], planes[1:]]
+        case 0:
+            org = planes
+        case _:
+            raise CustomNotImplementedError
+
+    if mode == "v":
+        org = [org]
+
+    stacked = stack_clips(org)
+
+    if clip.format.color_family == vs.RGB:
+        return core.std.RemoveFrameProps(stacked, Matrix.prop_key)
+
+    return stacked
+
+
 @overload
 def limiter(
     clip: vs.VideoNode,
@@ -975,11 +1111,7 @@ def limiter[**P](
     mask: bool = False,
     planes: Planes = None,
     func: FuncExcept | None = None,
-) -> Union[
-    vs.VideoNode,
-    Callable[P, vs.VideoNode],
-    Callable[[Callable[P, vs.VideoNode]], Callable[P, vs.VideoNode]],
-]:
+) -> vs.VideoNode | Callable[P, vs.VideoNode] | Callable[[Callable[P, vs.VideoNode]], Callable[P, vs.VideoNode]]:
     """
     Wraps [vszip.Limiter](https://github.com/dnjulek/vapoursynth-zip/wiki/Limiter)
     but only processes if clip format is not integer, a min/max val is specified or tv_range is True.
