@@ -1,7 +1,8 @@
 from __future__ import annotations
 
 from abc import abstractmethod
-from typing import TYPE_CHECKING, MutableMapping
+from collections.abc import MutableMapping
+from typing import TYPE_CHECKING
 
 from ..vs_proxy import VSObject, vs
 
@@ -45,43 +46,43 @@ class DynamicClipsCache[T](VSObject, dict[T, vs.VideoNode]):
         return super().__getitem__(key)
 
 
-class FramesCache[_NodeT: vs.RawNode, _FrameT: vs.RawFrame](VSObject, dict[int, _FrameT]):
-    def __init__(self, clip: _NodeT, cache_size: int = 10) -> None:
-        self.clip: _NodeT = clip
+class FramesCache[NodeT: vs.RawNode, FrameT: vs.RawFrame](VSObject, dict[int, FrameT]):
+    def __init__(self, clip: NodeT, cache_size: int = 10) -> None:
+        self.clip: NodeT = clip
         self.cache_size = cache_size
 
-    def add_frame(self, n: int, f: _FrameT) -> _FrameT:
+    def add_frame(self, n: int, f: FrameT) -> FrameT:
         f = f.copy()
         self[n] = f
         return f
 
-    def get_frame(self, n: int, f: _FrameT) -> _FrameT:
+    def get_frame(self, n: int, f: FrameT) -> FrameT:
         return self[n]
 
-    def __setitem__(self, key: int, value: _FrameT) -> None:
+    def __setitem__(self, key: int, value: FrameT) -> None:
         super().__setitem__(key, value)
 
         if len(self) > self.cache_size:
             del self[next(iter(self.keys()))]
 
-    def __getitem__(self, key: int) -> _FrameT:
+    def __getitem__(self, key: int) -> FrameT:
         if key not in self:
             self.add_frame(key, self.clip.get_frame(key))  # type: ignore[arg-type]
 
         return super().__getitem__(key)
 
 
-class NodeFramesCache[_NodeT: vs.RawNode, _FrameT: vs.RawFrame](VSObject, dict[_NodeT, FramesCache[_NodeT, _FrameT]]):
-    def _ensure_key(self, key: _NodeT) -> None:
+class NodeFramesCache[NodeT: vs.RawNode, FrameT: vs.RawFrame](VSObject, dict[NodeT, FramesCache[NodeT, FrameT]]):
+    def _ensure_key(self, key: NodeT) -> None:
         if key not in self:
             super().__setitem__(key, FramesCache(key))
 
-    def __setitem__(self, key: _NodeT, value: FramesCache[_NodeT, _FrameT]) -> None:
+    def __setitem__(self, key: NodeT, value: FramesCache[NodeT, FrameT]) -> None:
         self._ensure_key(key)
 
         return super().__setitem__(key, value)
 
-    def __getitem__(self, key: _NodeT) -> FramesCache[_NodeT, _FrameT]:
+    def __getitem__(self, key: NodeT) -> FramesCache[NodeT, FrameT]:
         self._ensure_key(key)
 
         return super().__getitem__(key)
@@ -90,15 +91,15 @@ class NodeFramesCache[_NodeT: vs.RawNode, _FrameT: vs.RawFrame](VSObject, dict[_
 class ClipFramesCache(NodeFramesCache[vs.VideoNode, vs.VideoFrame]): ...
 
 
-class NodesPropsCache[_NodeT: vs.RawNode](VSObject, dict[tuple[_NodeT, int], MutableMapping[str, "_PropValue"]]):
-    def __delitem__(self, key: tuple[_NodeT, int]) -> None:
+class NodesPropsCache[NodeT: vs.RawNode](VSObject, dict[tuple[NodeT, int], MutableMapping[str, "_PropValue"]]):
+    def __delitem__(self, key: tuple[NodeT, int]) -> None:
         if key not in self:
             return
 
         return super().__delitem__(key)
 
 
-def cache_clip[_NodeT: vs.RawNode](_clip: _NodeT, cache_size: int = 10) -> _NodeT:
+def cache_clip[NodeT: vs.RawNode](_clip: NodeT, cache_size: int = 10) -> NodeT:
     if isinstance(_clip, vs.VideoNode):
         cache = FramesCache[vs.VideoNode, vs.VideoFrame](_clip, cache_size)
 
