@@ -1,10 +1,11 @@
 from __future__ import annotations
 
+from collections.abc import Iterable, Iterator, Sequence
 from contextlib import AbstractContextManager
 from fractions import Fraction
 from math import floor
 from types import TracebackType
-from typing import Any, Iterable, Iterator, Self, Sequence, overload
+from typing import Any, Self, overload
 
 from jetpytools import MISSING, CustomValueError, MissingT, normalize_seq, to_arr
 from jetpytools import flatten as jetp_flatten
@@ -92,7 +93,7 @@ def match_clip(
     clip = clip.resize.Bicubic(ref.width, ref.height) if dimensions else clip
 
     if vformat:
-        clip = clip.resize.Bicubic(format=ref.format.id, matrix=Matrix.from_video(ref))
+        clip = clip.resize.Bicubic(format=ref.format, matrix=Matrix.from_video(ref))
 
     if matrices:
         clip = clip.std.SetFrameProps(
@@ -323,7 +324,7 @@ class padder:
                         ?
                     ?
                 ?
-            """.format(left=l_, right=r_ - 1, top=t_, bottom=b_ - 1)
+            """.format(left=l_, right=r_ - 1, top=t_, bottom=b_ - 1)  # noqa: UP032
                 for l_, r_, t_, b_ in pads
             ]
         )
@@ -514,9 +515,11 @@ def set_output(
         outputs = vs.get_outputs()
         nodes = list(flatten(node))
         indices = to_arr(index) if index is not None else [max(outputs, default=-1) + 1]
-        indices = normalize_seq(indices, len(nodes))
 
-        for idx, n in zip(indices, nodes):
+        while len(indices) < len(nodes):
+            indices.append(indices[-1] + 1)
+
+        for idx, n in zip(indices[: len(nodes)], nodes):
             n.set_output(idx)
     else:
         kwargs.setdefault("frame_depth", 2)
